@@ -68,7 +68,7 @@ class ConvertWorker(threading.Thread):
                       }
     self.readSettings()
     self.currentRunning=None
-    self.fnullName="/dev/null"
+    self.fnullName=os.devnull
     self.abortFlag = False
     if logging.getLogger().getEffectiveLevel() <= 3:
       self.stdoutFake=sys.stdout
@@ -86,7 +86,7 @@ class ConvertWorker(threading.Thread):
     """
     Check for the binary that needs to be executed. Not OS independent :(
     """
-    sts=subprocess.call("type %s 1>/dev/null 2>/dev/null"%commandString,shell=True)
+    sts=subprocess.call("type %s 1>%s 2>%s"%(commandString,os.devnull,os.devnull),shell=True)
     if sts == 0:
       return True
     else:
@@ -108,15 +108,16 @@ class ConvertWorker(threading.Thread):
         os.remove(file)
     return
   
-  def addResult(convertingFile,state,putInQueue = False):
+  def addResult(index,convertingFile,state,putInQueue = False):
     rc = False
     ConvertWorker.resultLock.acquire()
-    if convertingFile not in ConvertWorker.result.keys():
-      ConvertWorker.result[convertingFile] = {"state": state,
-                                              "step": "",
-                                              "stepState": ""}
+    if index not in ConvertWorker.result.keys():
+      ConvertWorker.result[index] = {"state": state,
+                                     "step": "",
+                                     "stepState": "",
+                                     "sourceFile":convertingFile}
       if True == putInQueue:
-        ConvertWorker.queue.put(convertingFile)
+        ConvertWorker.queue.put(index)
       rc = True
     ConvertWorker.resultLock.release()
     return rc
@@ -124,7 +125,8 @@ class ConvertWorker(threading.Thread):
   
   def run(self):
     while True:
-      self.convertingFile = ConvertWorker.queue.get()
+      self.index = ConvertWorker.queue.get()
+      self.convertingFile = ConvertWorker.result[self.index]["sourceFile"]
       if self.abortFlag:
         ConvertWorker.queue.task_done()
         continue
@@ -132,7 +134,7 @@ class ConvertWorker(threading.Thread):
       self.workingFile.append(self.convertingFile)
       self.filesToDelete = []
       self.p = None
-      ConvertWorker.addResult(self.convertingFile,"Converting 0%")
+      ConvertWorker.addResult(self.index,self.convertingFile,"Converting 0%")
       self.totalProgress = 0
       if True == os.path.isfile(self.convertingFile):
         if False:
@@ -157,20 +159,22 @@ class ConvertWorker(threading.Thread):
     try:
       ConvertWorker.resultLock.acquire()
       if "done" == state or "error" == state:
-        ConvertWorker.result[self.convertingFile] = {"state" : state, 
-                                                     "step": self.currentRunning,
-                                                     "stepState": state,
-                                                     "workingFile": self.workingFile.last()
-                                                     }
+        ConvertWorker.result[self.index] = {"state" : state, 
+                                            "step": self.currentRunning,
+                                            "stepState": state,
+                                            "workingFile": self.workingFile.last(),
+                                            "sourceFile":ConvertWorker.result[self.index]["sourceFile"]
+                                            }
       else:
         total=(int(self.totalProgress) + float(state.strip("%"))/100)/float(self.totalSteps)*100
-        ConvertWorker.result[self.convertingFile] = {"state": str(total)+"%",
-                                                     "step": self.currentRunning,
-                                                     "stepState": state,
-                                                     "workingFile": self.workingFile.last()
-                                                     }
+        ConvertWorker.result[self.index] = {"state": str(total)+"%",
+                                            "step": self.currentRunning,
+                                            "stepState": state,
+                                            "workingFile": self.workingFile.last(),
+                                            "sourceFile":ConvertWorker.result[self.index]["sourceFile"]
+                                            }
       logging.log(3,self.convertingFile)
-      logging.log(3,self.result[self.convertingFile])
+      logging.log(3,self.result[self.index])
       ConvertWorker.resultLock.release()
       return
     except ValueError:
@@ -197,7 +201,10 @@ class ConvertWorker(threading.Thread):
         convertedTime=float(strTime[0].split("=")[1])
 
       if None != convertedTime and None != totalTime:
-        toReturn="%i%%"%(convertedTime/totalTime*100.0)
+        try:
+          toReturn="%i%%"%(convertedTime/totalTime*100.0)
+        except:
+          toReturn="0%"
         return toReturn
     return "0%"
   
@@ -214,7 +221,10 @@ class ConvertWorker(threading.Thread):
             infos=i.split()
             progress=infos[1]
             total=infos[4]
-            percentage=float(progress)/float(total)*100
+            try:
+              percentage=float(progress)/float(total)*100
+            except:
+              percentage=0
             toReturn="%i%%"%(percentage)
             return toReturn
     return "0%"
@@ -277,7 +287,7 @@ class ConvertWorker(threading.Thread):
                                self.programList["ffmpeg"]["path"],
                                "-y",
                                "-ab",
-                               "128k",
+                               self.settings["converter.kbps"],
                                "-i",
                                self.convertingFile,
                                self.workingFile.last()
@@ -302,6 +312,8 @@ class ConvertWorker(threading.Thread):
     self.p=subprocess.Popen([
                              self.programList["lame"]["path"],
                              "-h",
+                             "-b",
+                             self.settings["converter.kbps"],
                              toConvert,
                              self.workingFile.last()
                              ],
@@ -428,6 +440,7 @@ class ConvertWorker(threading.Thread):
   
   def prepare(self):
     self.abortFlag = False
+    return
 
 if __name__== '__main__':
   logging.basicConfig(
